@@ -368,6 +368,7 @@ public class LiferayUserManager implements UserManager {
 			UserLocalServiceUtil.updateUser(added);
 			_log.debug("CreateUser " + lastName + " SUCCESS");
 			UserLocalServiceUtil.updateAgreedToTermsOfUse(added.getUserId(), true);
+			UserLocalServiceUtil.updateEmailAddressVerified(added.getUserId(), true);
 			UserLocalServiceUtil.updatePasswordReset(added.getUserId(), forcePasswordReset);
 			if (reminderQuestion == null || reminderQuestion.compareTo("") == 0) 
 				reminderQuestion = "Unknown question";				
@@ -375,6 +376,7 @@ public class LiferayUserManager implements UserManager {
 				reminderAnswer = "Unknown answer";				
 			UserLocalServiceUtil.updateReminderQuery(added.getUserId(), reminderQuestion, reminderAnswer);
 			_log.debug("User " + lastName + " has agreed to ToU");
+			_log.debug("User " + lastName + " has verified the Email");
 			_log.debug("User " + lastName + " updatePasswordReset & updateReminderQuery");
 
 			//try save the location/industry
@@ -577,6 +579,35 @@ public class LiferayUserManager implements UserManager {
 	 * {@inheritDoc}
 	 */
 	@Override
+	public List<GCubeUser> listUsers(int start, int end) throws UserManagementSystemException {
+		List<GCubeUser> toReturn = new ArrayList<GCubeUser>();
+		try {
+			List<User> lrUsers = UserLocalServiceUtil.getUsers(start,  end);
+			for (User user : lrUsers) {
+				if (user.isActive())
+					toReturn.add(mapLRUser(user));
+			}
+		} catch (SystemException e) {
+			throw new UserManagementSystemException(e.getMessage(), e);
+		} catch (PortalException e) {
+			e.printStackTrace();
+		}
+		return toReturn;
+	}
+	/**
+	 * {@inheritDoc}
+	 */
+	public int getUsersCount() throws UserManagementSystemException {
+		try {
+			return UserLocalServiceUtil.getUsersCount();
+		} catch (SystemException e) {
+			throw new UserManagementSystemException(e.getMessage(), e);
+		}
+	}
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
 	public List<GCubeUser> listUsersByGroup(long groupId) throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault {
 		List<GCubeUser> toReturn = new ArrayList<GCubeUser>();
 		try {
@@ -591,6 +622,35 @@ public class LiferayUserManager implements UserManager {
 		}
 		return toReturn;
 	}
+
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	public List<GCubeUser> listUsersByGroup(long groupId, int start, int end) throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault {
+		List<GCubeUser> toReturn = new ArrayList<GCubeUser>();
+		try {
+			for (User user : UserLocalServiceUtil.getGroupUsers(groupId, start, end)) {
+				if (user.isActive())
+					toReturn.add(mapLRUser(user));
+			}
+		} catch (PortalException e) {
+			throw new GroupRetrievalFault("listUsersByGroup not existing group", groupId, e);
+		} catch (SystemException e) {
+			e.printStackTrace();
+		}
+		return toReturn;
+	}
+	/**
+	 * {@inheritDoc}
+	 */
+	public int getGroupUsersCount(long groupId) throws GroupRetrievalFault {
+		try {
+			return UserLocalServiceUtil.getGroupUsersCount(groupId);
+		} catch (SystemException e) {
+			throw new GroupRetrievalFault("listUsersByGroup not existing group", groupId, e);
+		}
+	}
 	/**
 	 * {@inheritDoc}
 	 */
@@ -615,6 +675,28 @@ public class LiferayUserManager implements UserManager {
 		}
 		return toReturn;
 	}
+	/**
+	 * {@inheritDoc}
+	 */
+	public List<GCubeUser> searchUsersByGroup(String keywords, long groupId) throws GroupRetrievalFault {
+		List<GCubeUser> toReturn = new ArrayList<GCubeUser>();
+		try {
+			OrderByComparator comparator = OrderByComparatorFactoryUtil.create("User_", "screenname", true);
+			LinkedHashMap<String, Object> params = new LinkedHashMap<>();
+			params.put("usersGroups", groupId); 
+			List<User> usersByGroup = UserLocalServiceUtil.search(
+					ManagementUtils.getCompany().getCompanyId(), keywords, 0, params, QueryUtil.ALL_POS, QueryUtil.ALL_POS, comparator);
+			for (User user : usersByGroup) {
+				if (user.isActive())
+					toReturn.add(mapLRUser(user));
+			}
+		} catch (PortalException e) {
+			throw new GroupRetrievalFault("listUsersByGroup not existing group", groupId, e);
+		} catch (SystemException e) {
+			e.printStackTrace();
+		}
+		return toReturn;
+	}
 	/**
 	 * {@inheritDoc}
 	 */
@@ -650,7 +732,9 @@ public class LiferayUserManager implements UserManager {
 					List<Role> userRoles = RoleServiceUtil.getUserGroupRoles(userId, groupId);
 					List<GCubeRole> toAdd = new ArrayList<GCubeRole>();
 					for (Role role : userRoles) {
-						toAdd.add(LiferayRoleManager.mapLRRole(role));
+						if (! (role.getType() == LiferayRoleManager.ROLE_TYPE && role.getName().startsWith("Site"))) {
+							toAdd.add(LiferayRoleManager.mapLRRole(role));
+						}
 					}
 					toReturn.put(mapLRUser(user), toAdd);
 				}					
